# coding: utf-8

# flake8: noqa

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from CommandCenter.api.access_logs_api import AccessLogsApi
from CommandCenter.api.cloud_settings_api import CloudSettingsApi
from CommandCenter.api.cloud_users_api import CloudUsersApi
from CommandCenter.api.clouds_api import CloudsApi
from CommandCenter.api.comments_api import CommentsApi
from CommandCenter.api.computes_api import ComputesApi
from CommandCenter.api.custom_networks_api import CustomNetworksApi
from CommandCenter.api.drive_api import DriveApi
from CommandCenter.api.drive_types_api import DriveTypesApi
from CommandCenter.api.engine_types_api import EngineTypesApi
from CommandCenter.api.fault_domains_api import FaultDomainsApi
from CommandCenter.api.images_api import ImagesApi
from CommandCenter.api.logs_api import LogsApi
from CommandCenter.api.remote_authentications_api import RemoteAuthenticationsApi
from CommandCenter.api.roles_api import RolesApi
from CommandCenter.api.software_install_api import SoftwareInstallApi
from CommandCenter.api.storage_nodes_api import StorageNodesApi
from CommandCenter.api.users_api import UsersApi
from CommandCenter.api.vlan_api import VLANApi
from CommandCenter.api.vpsa_api import VPSAApi
from CommandCenter.api.vpsa_object_storage_api import VPSAObjectStorageApi
from CommandCenter.api.volume_api import VolumeApi

# import ApiClient
from CommandCenter.api_client import ApiClient
from CommandCenter.configuration import Configuration
# import models into sdk package
from CommandCenter.models.add_address_to_remote_rsyslog_server_list import AddAddressToRemoteRsyslogServerList
from CommandCenter.models.add_cloud_control_ip_whitelisting_entries import AddCloudControlIpWhitelistingEntries
from CommandCenter.models.add_drives import AddDrives
from CommandCenter.models.add_drives_to_zios import AddDrivesToZios
from CommandCenter.models.add_ip_range_to_custom_net import AddIpRangeToCustomNet
from CommandCenter.models.add_node import AddNode
from CommandCenter.models.add_provisioned_vlan_or_range import AddProvisionedVlanOrRange
from CommandCenter.models.add_proxy_virtual_controller_zios import AddProxyVirtualControllerZios
from CommandCenter.models.add_virtual_nets_to_zios import AddVirtualNetsToZios
from CommandCenter.models.add_virtual_network_interface import AddVirtualNetworkInterface
from CommandCenter.models.add_vpsa_endpoints_conf_for_upload_types import AddVpsaEndpointsConfForUploadTypes
from CommandCenter.models.add_zios_endpoints_configs_for_upload_types import AddZiosEndpointsConfigsForUploadTypes
from CommandCenter.models.allocate_vlan import AllocateVlan
from CommandCenter.models.allocate_vlan_to_cloud_user import AllocateVlanToCloudUser
from CommandCenter.models.assign_public_ip import AssignPublicIp
from CommandCenter.models.assign_public_ip_zios import AssignPublicIpZios
from CommandCenter.models.change_cache import ChangeCache
from CommandCenter.models.change_engine_type_zios import ChangeEngineTypeZios
from CommandCenter.models.cloud_upgrade import CloudUpgrade
from CommandCenter.models.cloudscloud_namesettingsadd_cloud_control_ip_whitelisting_entries_json_entries import CloudscloudNamesettingsaddCloudControlIpWhitelistingEntriesJsonEntries
from CommandCenter.models.cloudscloud_namesettingsendpoints_config_json_endpoints_config import CloudscloudNamesettingsendpointsConfigJsonEndpointsConfig
from CommandCenter.models.compute import Compute
from CommandCenter.models.continue_policy_rebalance_zios import ContinuePolicyRebalanceZios
from CommandCenter.models.create_cloud_vms_zsnap import CreateCloudVmsZsnap
from CommandCenter.models.create_comment import CreateComment
from CommandCenter.models.create_compute import CreateCompute
from CommandCenter.models.create_custom_network import CreateCustomNetwork
from CommandCenter.models.create_endpoint import CreateEndpoint
from CommandCenter.models.create_endpoints_config import CreateEndpointsConfig
from CommandCenter.models.create_new_vpsa_upload_endpoint import CreateNewVpsaUploadEndpoint
from CommandCenter.models.create_remote_authentication_server import CreateRemoteAuthenticationServer
from CommandCenter.models.create_role import CreateRole
from CommandCenter.models.create_storage_policy_zios import CreateStoragePolicyZios
from CommandCenter.models.create_user import CreateUser
from CommandCenter.models.create_vpsa_endpoints_conf_for_upload_types import CreateVpsaEndpointsConfForUploadTypes
from CommandCenter.models.create_zios_endpoints_configs_for_upload_types import CreateZiosEndpointsConfigsForUploadTypes
from CommandCenter.models.create_zios_upload_endpoint import CreateZiosUploadEndpoint
from CommandCenter.models.create_zsnap import CreateZsnap
from CommandCenter.models.create_zsnap_zios import CreateZsnapZios
from CommandCenter.models.deallocate_vlan_to_cloud_user import DeallocateVlanToCloudUser
from CommandCenter.models.default import Default
from CommandCenter.models.default_response import DefaultResponse
from CommandCenter.models.delete_address_from_remote_rsyslog_server_list import DeleteAddressFromRemoteRsyslogServerList
from CommandCenter.models.delete_cloud_control_ip_whitelisting_entries import DeleteCloudControlIpWhitelistingEntries
from CommandCenter.models.delete_endpoint import DeleteEndpoint
from CommandCenter.models.delete_endpoints_config import DeleteEndpointsConfig
from CommandCenter.models.delete_tenant import DeleteTenant
from CommandCenter.models.delete_vpsa_endpoints_conf_for_upload_types import DeleteVpsaEndpointsConfForUploadTypes
from CommandCenter.models.delete_vpsa_upload_endpoint import DeleteVpsaUploadEndpoint
from CommandCenter.models.delete_vrid_from_vlan import DeleteVridFromVlan
from CommandCenter.models.delete_zios_endpoints_config_for_upload_types import DeleteZiosEndpointsConfigForUploadTypes
from CommandCenter.models.delete_zios_upload_endpoint import DeleteZiosUploadEndpoint
from CommandCenter.models.download_package import DownloadPackage
from CommandCenter.models.edit_comment import EditComment
from CommandCenter.models.edit_compute import EditCompute
from CommandCenter.models.edit_role import EditRole
from CommandCenter.models.enabled import Enabled
from CommandCenter.models.erase_package import ErasePackage
from CommandCenter.models.error import Error
from CommandCenter.models.evacoate_vc_from_sn import EvacoateVcFromSn
from CommandCenter.models.failover_vpsa import FailoverVpsa
from CommandCenter.models.faulty import Faulty
from CommandCenter.models.get_user_api_key import GetUserApiKey
from CommandCenter.models.get_vpsa_capacity_trend import GetVpsaCapacityTrend
from CommandCenter.models.get_vpsa_endpoint_configs_by_upload_types import GetVpsaEndpointConfigsByUploadTypes
from CommandCenter.models.get_vpsa_settings import GetVpsaSettings
from CommandCenter.models.get_zios_upload_endpoints import GetZiosUploadEndpoints
from CommandCenter.models.import_users_from_remote_directory import ImportUsersFromRemoteDirectory
from CommandCenter.models.inline_response200 import InlineResponse200
from CommandCenter.models.inline_response2001 import InlineResponse2001
from CommandCenter.models.inline_response20010 import InlineResponse20010
from CommandCenter.models.inline_response200100 import InlineResponse200100
from CommandCenter.models.inline_response200100_capacity_trend import InlineResponse200100CapacityTrend
from CommandCenter.models.inline_response200100_capacity_trend_dates import InlineResponse200100CapacityTrendDates
from CommandCenter.models.inline_response200101 import InlineResponse200101
from CommandCenter.models.inline_response200102 import InlineResponse200102
from CommandCenter.models.inline_response200103 import InlineResponse200103
from CommandCenter.models.inline_response200104 import InlineResponse200104
from CommandCenter.models.inline_response200105 import InlineResponse200105
from CommandCenter.models.inline_response200106 import InlineResponse200106
from CommandCenter.models.inline_response200107 import InlineResponse200107
from CommandCenter.models.inline_response200108 import InlineResponse200108
from CommandCenter.models.inline_response200109 import InlineResponse200109
from CommandCenter.models.inline_response20010_comments import InlineResponse20010Comments
from CommandCenter.models.inline_response20010_comments_comment import InlineResponse20010CommentsComment
from CommandCenter.models.inline_response20011 import InlineResponse20011
from CommandCenter.models.inline_response200110 import InlineResponse200110
from CommandCenter.models.inline_response200111 import InlineResponse200111
from CommandCenter.models.inline_response200112 import InlineResponse200112
from CommandCenter.models.inline_response200113 import InlineResponse200113
from CommandCenter.models.inline_response200114 import InlineResponse200114
from CommandCenter.models.inline_response200115 import InlineResponse200115
from CommandCenter.models.inline_response200116 import InlineResponse200116
from CommandCenter.models.inline_response200117 import InlineResponse200117
from CommandCenter.models.inline_response200118 import InlineResponse200118
from CommandCenter.models.inline_response200118_vpsa_upload_endpoints import InlineResponse200118VpsaUploadEndpoints
from CommandCenter.models.inline_response200119 import InlineResponse200119
from CommandCenter.models.inline_response20012 import InlineResponse20012
from CommandCenter.models.inline_response200120 import InlineResponse200120
from CommandCenter.models.inline_response200121 import InlineResponse200121
from CommandCenter.models.inline_response200122 import InlineResponse200122
from CommandCenter.models.inline_response200122_vpsa_endpoint_configs import InlineResponse200122VpsaEndpointConfigs
from CommandCenter.models.inline_response200123 import InlineResponse200123
from CommandCenter.models.inline_response200124 import InlineResponse200124
from CommandCenter.models.inline_response200125 import InlineResponse200125
from CommandCenter.models.inline_response200126 import InlineResponse200126
from CommandCenter.models.inline_response200126_fault_domains import InlineResponse200126FaultDomains
from CommandCenter.models.inline_response200127 import InlineResponse200127
from CommandCenter.models.inline_response200128 import InlineResponse200128
from CommandCenter.models.inline_response200129 import InlineResponse200129
from CommandCenter.models.inline_response200129_network_configuration import InlineResponse200129NetworkConfiguration
from CommandCenter.models.inline_response200129_network_configuration_vc0 import InlineResponse200129NetworkConfigurationVc0
from CommandCenter.models.inline_response200129_network_configuration_vc1 import InlineResponse200129NetworkConfigurationVc1
from CommandCenter.models.inline_response200129_network_configuration_vc2 import InlineResponse200129NetworkConfigurationVc2
from CommandCenter.models.inline_response200129_zioses import InlineResponse200129Zioses
from CommandCenter.models.inline_response20013 import InlineResponse20013
from CommandCenter.models.inline_response200130 import InlineResponse200130
from CommandCenter.models.inline_response200131 import InlineResponse200131
from CommandCenter.models.inline_response200131_drives import InlineResponse200131Drives
from CommandCenter.models.inline_response200132 import InlineResponse200132
from CommandCenter.models.inline_response200133 import InlineResponse200133
from CommandCenter.models.inline_response200133_virtual_controllers import InlineResponse200133VirtualControllers
from CommandCenter.models.inline_response200134 import InlineResponse200134
from CommandCenter.models.inline_response200134_ring_balance import InlineResponse200134RingBalance
from CommandCenter.models.inline_response200134_zios_storage_policies import InlineResponse200134ZiosStoragePolicies
from CommandCenter.models.inline_response200135 import InlineResponse200135
from CommandCenter.models.inline_response200135_load_balancer import InlineResponse200135LoadBalancer
from CommandCenter.models.inline_response200135_master_vc import InlineResponse200135MasterVc
from CommandCenter.models.inline_response200135_protectionzone import InlineResponse200135Protectionzone
from CommandCenter.models.inline_response200135_vcs import InlineResponse200135Vcs
from CommandCenter.models.inline_response200136 import InlineResponse200136
from CommandCenter.models.inline_response200136_accounts import InlineResponse200136Accounts
from CommandCenter.models.inline_response200137 import InlineResponse200137
from CommandCenter.models.inline_response200138 import InlineResponse200138
from CommandCenter.models.inline_response200139 import InlineResponse200139
from CommandCenter.models.inline_response20014 import InlineResponse20014
from CommandCenter.models.inline_response200140 import InlineResponse200140
from CommandCenter.models.inline_response200141 import InlineResponse200141
from CommandCenter.models.inline_response200142 import InlineResponse200142
from CommandCenter.models.inline_response200143 import InlineResponse200143
from CommandCenter.models.inline_response200144 import InlineResponse200144
from CommandCenter.models.inline_response200145 import InlineResponse200145
from CommandCenter.models.inline_response200146 import InlineResponse200146
from CommandCenter.models.inline_response200147 import InlineResponse200147
from CommandCenter.models.inline_response200148 import InlineResponse200148
from CommandCenter.models.inline_response200149 import InlineResponse200149
from CommandCenter.models.inline_response20015 import InlineResponse20015
from CommandCenter.models.inline_response200150 import InlineResponse200150
from CommandCenter.models.inline_response200151 import InlineResponse200151
from CommandCenter.models.inline_response200152 import InlineResponse200152
from CommandCenter.models.inline_response20015_custom_networks import InlineResponse20015CustomNetworks
from CommandCenter.models.inline_response20015_custom_networks_custom_network import InlineResponse20015CustomNetworksCustomNetwork
from CommandCenter.models.inline_response20016 import InlineResponse20016
from CommandCenter.models.inline_response20016_custom_network import InlineResponse20016CustomNetwork
from CommandCenter.models.inline_response20017 import InlineResponse20017
from CommandCenter.models.inline_response20017_custom_network import InlineResponse20017CustomNetwork
from CommandCenter.models.inline_response20018 import InlineResponse20018
from CommandCenter.models.inline_response20018_drives import InlineResponse20018Drives
from CommandCenter.models.inline_response20019 import InlineResponse20019
from CommandCenter.models.inline_response2001_clouds import InlineResponse2001Clouds
from CommandCenter.models.inline_response2001_inventory import InlineResponse2001Inventory
from CommandCenter.models.inline_response2001_networking import InlineResponse2001Networking
from CommandCenter.models.inline_response2001_resources import InlineResponse2001Resources
from CommandCenter.models.inline_response2002 import InlineResponse2002
from CommandCenter.models.inline_response20020 import InlineResponse20020
from CommandCenter.models.inline_response20020_comments import InlineResponse20020Comments
from CommandCenter.models.inline_response20020_comments_comment import InlineResponse20020CommentsComment
from CommandCenter.models.inline_response20021 import InlineResponse20021
from CommandCenter.models.inline_response20021_details import InlineResponse20021Details
from CommandCenter.models.inline_response20022 import InlineResponse20022
from CommandCenter.models.inline_response20023 import InlineResponse20023
from CommandCenter.models.inline_response20024 import InlineResponse20024
from CommandCenter.models.inline_response20025 import InlineResponse20025
from CommandCenter.models.inline_response20025_iops import InlineResponse20025Iops
from CommandCenter.models.inline_response20025_iotime import InlineResponse20025Iotime
from CommandCenter.models.inline_response20025_performances import InlineResponse20025Performances
from CommandCenter.models.inline_response20026 import InlineResponse20026
from CommandCenter.models.inline_response20026_drive_types import InlineResponse20026DriveTypes
from CommandCenter.models.inline_response20026_drive_types_drive_type import InlineResponse20026DriveTypesDriveType
from CommandCenter.models.inline_response20026_drive_types_drive_type_inventory import InlineResponse20026DriveTypesDriveTypeInventory
from CommandCenter.models.inline_response20027 import InlineResponse20027
from CommandCenter.models.inline_response20027_drive_type import InlineResponse20027DriveType
from CommandCenter.models.inline_response20028 import InlineResponse20028
from CommandCenter.models.inline_response20028_drives import InlineResponse20028Drives
from CommandCenter.models.inline_response20028_drives_drive import InlineResponse20028DrivesDrive
from CommandCenter.models.inline_response20029 import InlineResponse20029
from CommandCenter.models.inline_response20029_engine_types import InlineResponse20029EngineTypes
from CommandCenter.models.inline_response20029_engine_types_engine_type import InlineResponse20029EngineTypesEngineType
from CommandCenter.models.inline_response2002_cloud import InlineResponse2002Cloud
from CommandCenter.models.inline_response2002_cloud_networking import InlineResponse2002CloudNetworking
from CommandCenter.models.inline_response2003 import InlineResponse2003
from CommandCenter.models.inline_response20030 import InlineResponse20030
from CommandCenter.models.inline_response20031 import InlineResponse20031
from CommandCenter.models.inline_response20031_app_engine_types import InlineResponse20031AppEngineTypes
from CommandCenter.models.inline_response20031_app_engine_types_app_engine_type import InlineResponse20031AppEngineTypesAppEngineType
from CommandCenter.models.inline_response20032 import InlineResponse20032
from CommandCenter.models.inline_response20033 import InlineResponse20033
from CommandCenter.models.inline_response20033_images import InlineResponse20033Images
from CommandCenter.models.inline_response20034 import InlineResponse20034
from CommandCenter.models.inline_response20035 import InlineResponse20035
from CommandCenter.models.inline_response20035_logs import InlineResponse20035Logs
from CommandCenter.models.inline_response20036 import InlineResponse20036
from CommandCenter.models.inline_response20037 import InlineResponse20037
from CommandCenter.models.inline_response20038 import InlineResponse20038
from CommandCenter.models.inline_response20038_drives import InlineResponse20038Drives
from CommandCenter.models.inline_response20038_information import InlineResponse20038Information
from CommandCenter.models.inline_response20038_information_cpu_infos import InlineResponse20038InformationCpuInfos
from CommandCenter.models.inline_response20038_information_cpu_infos_cpu_info import InlineResponse20038InformationCpuInfosCpuInfo
from CommandCenter.models.inline_response20038_information_mr_info import InlineResponse20038InformationMrInfo
from CommandCenter.models.inline_response20038_information_mr_info_adp_info import InlineResponse20038InformationMrInfoAdpInfo
from CommandCenter.models.inline_response20038_ips import InlineResponse20038Ips
from CommandCenter.models.inline_response20038_license import InlineResponse20038License
from CommandCenter.models.inline_response20038_macs import InlineResponse20038Macs
from CommandCenter.models.inline_response20038_nic_information import InlineResponse20038NicInformation
from CommandCenter.models.inline_response20038_nodes import InlineResponse20038Nodes
from CommandCenter.models.inline_response20038_resources import InlineResponse20038Resources
from CommandCenter.models.inline_response20038_services import InlineResponse20038Services
from CommandCenter.models.inline_response20039 import InlineResponse20039
from CommandCenter.models.inline_response2003_public_ips import InlineResponse2003PublicIps
from CommandCenter.models.inline_response2004 import InlineResponse2004
from CommandCenter.models.inline_response20040 import InlineResponse20040
from CommandCenter.models.inline_response20040_drives import InlineResponse20040Drives
from CommandCenter.models.inline_response20041 import InlineResponse20041
from CommandCenter.models.inline_response20041_cache_partitions import InlineResponse20041CachePartitions
from CommandCenter.models.inline_response20041_cache_partitions_cache_partition import InlineResponse20041CachePartitionsCachePartition
from CommandCenter.models.inline_response20041_cache_partitions_cache_partition_drive import InlineResponse20041CachePartitionsCachePartitionDrive
from CommandCenter.models.inline_response20042 import InlineResponse20042
from CommandCenter.models.inline_response20042_virtual_controllers import InlineResponse20042VirtualControllers
from CommandCenter.models.inline_response20042_virtual_controllers_virtual_controller import InlineResponse20042VirtualControllersVirtualController
from CommandCenter.models.inline_response20043 import InlineResponse20043
from CommandCenter.models.inline_response20044 import InlineResponse20044
from CommandCenter.models.inline_response20044_services import InlineResponse20044Services
from CommandCenter.models.inline_response20045 import InlineResponse20045
from CommandCenter.models.inline_response20045_remotes import InlineResponse20045Remotes
from CommandCenter.models.inline_response20046 import InlineResponse20046
from CommandCenter.models.inline_response20047 import InlineResponse20047
from CommandCenter.models.inline_response20047_remote import InlineResponse20047Remote
from CommandCenter.models.inline_response20048 import InlineResponse20048
from CommandCenter.models.inline_response20048_imported_users import InlineResponse20048ImportedUsers
from CommandCenter.models.inline_response20049 import InlineResponse20049
from CommandCenter.models.inline_response2005 import InlineResponse2005
from CommandCenter.models.inline_response20050 import InlineResponse20050
from CommandCenter.models.inline_response20050_role import InlineResponse20050Role
from CommandCenter.models.inline_response20050_roles import InlineResponse20050Roles
from CommandCenter.models.inline_response20051 import InlineResponse20051
from CommandCenter.models.inline_response20052 import InlineResponse20052
from CommandCenter.models.inline_response20053 import InlineResponse20053
from CommandCenter.models.inline_response20054 import InlineResponse20054
from CommandCenter.models.inline_response20054_cache_or_afa_meta_drives_settings import InlineResponse20054CacheOrAfaMetaDrivesSettings
from CommandCenter.models.inline_response20054_default_ccvm_engine import InlineResponse20054DefaultCcvmEngine
from CommandCenter.models.inline_response20054_general import InlineResponse20054General
from CommandCenter.models.inline_response20054_password_status import InlineResponse20054PasswordStatus
from CommandCenter.models.inline_response20054_recycle_bin import InlineResponse20054RecycleBin
from CommandCenter.models.inline_response20054_security import InlineResponse20054Security
from CommandCenter.models.inline_response20054_support_tickets import InlineResponse20054SupportTickets
from CommandCenter.models.inline_response20054_ticket_threshold import InlineResponse20054TicketThreshold
from CommandCenter.models.inline_response20054_vpsa import InlineResponse20054Vpsa
from CommandCenter.models.inline_response20054_zsnap_settings import InlineResponse20054ZsnapSettings
from CommandCenter.models.inline_response20054_zsnap_settings_data import InlineResponse20054ZsnapSettingsData
from CommandCenter.models.inline_response20055 import InlineResponse20055
from CommandCenter.models.inline_response20056 import InlineResponse20056
from CommandCenter.models.inline_response20057 import InlineResponse20057
from CommandCenter.models.inline_response20058 import InlineResponse20058
from CommandCenter.models.inline_response20059 import InlineResponse20059
from CommandCenter.models.inline_response2006 import InlineResponse2006
from CommandCenter.models.inline_response20060 import InlineResponse20060
from CommandCenter.models.inline_response20061 import InlineResponse20061
from CommandCenter.models.inline_response20062 import InlineResponse20062
from CommandCenter.models.inline_response20062_clouduploadendpoints import InlineResponse20062Clouduploadendpoints
from CommandCenter.models.inline_response20063 import InlineResponse20063
from CommandCenter.models.inline_response20064 import InlineResponse20064
from CommandCenter.models.inline_response20065 import InlineResponse20065
from CommandCenter.models.inline_response20066 import InlineResponse20066
from CommandCenter.models.inline_response20066_cloudendpointconfigs import InlineResponse20066Cloudendpointconfigs
from CommandCenter.models.inline_response20067 import InlineResponse20067
from CommandCenter.models.inline_response20068 import InlineResponse20068
from CommandCenter.models.inline_response20069 import InlineResponse20069
from CommandCenter.models.inline_response2006_vpsazone_group_storage_policy_types import InlineResponse2006VpsazoneGroupStoragePolicyTypes
from CommandCenter.models.inline_response2007 import InlineResponse2007
from CommandCenter.models.inline_response20070 import InlineResponse20070
from CommandCenter.models.inline_response20071 import InlineResponse20071
from CommandCenter.models.inline_response20071_ccvmipwhitelistentries import InlineResponse20071Ccvmipwhitelistentries
from CommandCenter.models.inline_response20072 import InlineResponse20072
from CommandCenter.models.inline_response20073 import InlineResponse20073
from CommandCenter.models.inline_response20074 import InlineResponse20074
from CommandCenter.models.inline_response20075 import InlineResponse20075
from CommandCenter.models.inline_response20075_message import InlineResponse20075Message
from CommandCenter.models.inline_response20075_message_sns import InlineResponse20075MessageSns
from CommandCenter.models.inline_response20076 import InlineResponse20076
from CommandCenter.models.inline_response20076_message import InlineResponse20076Message
from CommandCenter.models.inline_response20076_message_pkgs import InlineResponse20076MessagePkgs
from CommandCenter.models.inline_response20077 import InlineResponse20077
from CommandCenter.models.inline_response20078 import InlineResponse20078
from CommandCenter.models.inline_response20079 import InlineResponse20079
from CommandCenter.models.inline_response2007_cloud_users import InlineResponse2007CloudUsers
from CommandCenter.models.inline_response2008 import InlineResponse2008
from CommandCenter.models.inline_response20080 import InlineResponse20080
from CommandCenter.models.inline_response20080_message import InlineResponse20080Message
from CommandCenter.models.inline_response20080_message_actions import InlineResponse20080MessageActions
from CommandCenter.models.inline_response20080_message_data import InlineResponse20080MessageData
from CommandCenter.models.inline_response20080_message_param import InlineResponse20080MessageParam
from CommandCenter.models.inline_response20080_message_steps import InlineResponse20080MessageSteps
from CommandCenter.models.inline_response20081 import InlineResponse20081
from CommandCenter.models.inline_response20082 import InlineResponse20082
from CommandCenter.models.inline_response20083 import InlineResponse20083
from CommandCenter.models.inline_response20083_users import InlineResponse20083Users
from CommandCenter.models.inline_response20084 import InlineResponse20084
from CommandCenter.models.inline_response20084_user import InlineResponse20084User
from CommandCenter.models.inline_response20084_user_roles import InlineResponse20084UserRoles
from CommandCenter.models.inline_response20085 import InlineResponse20085
from CommandCenter.models.inline_response20086 import InlineResponse20086
from CommandCenter.models.inline_response20087 import InlineResponse20087
from CommandCenter.models.inline_response20087_vlans import InlineResponse20087Vlans
from CommandCenter.models.inline_response20088 import InlineResponse20088
from CommandCenter.models.inline_response20089 import InlineResponse20089
from CommandCenter.models.inline_response2008_cloud_user import InlineResponse2008CloudUser
from CommandCenter.models.inline_response2009 import InlineResponse2009
from CommandCenter.models.inline_response20090 import InlineResponse20090
from CommandCenter.models.inline_response20091 import InlineResponse20091
from CommandCenter.models.inline_response20091_network_configuration import InlineResponse20091NetworkConfiguration
from CommandCenter.models.inline_response20091_network_configuration_vc0 import InlineResponse20091NetworkConfigurationVc0
from CommandCenter.models.inline_response20091_network_configuration_vc1 import InlineResponse20091NetworkConfigurationVc1
from CommandCenter.models.inline_response20091_vpsas import InlineResponse20091Vpsas
from CommandCenter.models.inline_response20092 import InlineResponse20092
from CommandCenter.models.inline_response20093 import InlineResponse20093
from CommandCenter.models.inline_response20093_drives import InlineResponse20093Drives
from CommandCenter.models.inline_response20094 import InlineResponse20094
from CommandCenter.models.inline_response20095 import InlineResponse20095
from CommandCenter.models.inline_response20095_virtual_controllers import InlineResponse20095VirtualControllers
from CommandCenter.models.inline_response20095_virtual_controllers_virtual_controller import InlineResponse20095VirtualControllersVirtualController
from CommandCenter.models.inline_response20096 import InlineResponse20096
from CommandCenter.models.inline_response20096_raid_groups import InlineResponse20096RaidGroups
from CommandCenter.models.inline_response20096_raid_groups_raid_group import InlineResponse20096RaidGroupsRaidGroup
from CommandCenter.models.inline_response20097 import InlineResponse20097
from CommandCenter.models.inline_response20097_pools import InlineResponse20097Pools
from CommandCenter.models.inline_response20097_pools_pool import InlineResponse20097PoolsPool
from CommandCenter.models.inline_response20098 import InlineResponse20098
from CommandCenter.models.inline_response20098_compatible_virtual_networks import InlineResponse20098CompatibleVirtualNetworks
from CommandCenter.models.inline_response20099 import InlineResponse20099
from CommandCenter.models.inline_response20099_virtual_networks import InlineResponse20099VirtualNetworks
from CommandCenter.models.inline_response2009_vlans import InlineResponse2009Vlans
from CommandCenter.models.inline_response200_access_logs import InlineResponse200AccessLogs
from CommandCenter.models.install_sn import InstallSn
from CommandCenter.models.license_storage_node import LicenseStorageNode
from CommandCenter.models.list_all_vpsa_upload_endpoints import ListAllVpsaUploadEndpoints
from CommandCenter.models.list_cloud_public_ips import ListCloudPublicIps
from CommandCenter.models.list_zios_endpoints_configs_by_upload_types import ListZiosEndpointsConfigsByUploadTypes
from CommandCenter.models.maintenance_mode import MaintenanceMode
from CommandCenter.models.move_virtual_net_to_diff_sn import MoveVirtualNetToDiffSn
from CommandCenter.models.pause_policy_rebalance_zios import PausePolicyRebalanceZios
from CommandCenter.models.populate_vrid_in_vlan import PopulateVridInVlan
from CommandCenter.models.reboot_storage_node import RebootStorageNode
from CommandCenter.models.regenerate_user_api_token import RegenerateUserApiToken
from CommandCenter.models.register_images import RegisterImages
from CommandCenter.models.remove_ip_range_from_custom_net import RemoveIpRangeFromCustomNet
from CommandCenter.models.remove_virtual_nets_from_zios import RemoveVirtualNetsFromZios
from CommandCenter.models.remove_virtual_network_interface import RemoveVirtualNetworkInterface
from CommandCenter.models.reschedule_upgrade_vpsa import RescheduleUpgradeVpsa
from CommandCenter.models.reserve_vrid_for_vlan import ReserveVridForVlan
from CommandCenter.models.set_automatic_drive_replacement import SetAutomaticDriveReplacement
from CommandCenter.models.set_ccvm_default_engine import SetCcvmDefaultEngine
from CommandCenter.models.set_cube_from_local_repo import SetCubeFromLocalRepo
from CommandCenter.models.set_default_vlan_for_cloud_user import SetDefaultVlanForCloudUser
from CommandCenter.models.set_remote_region_backend_protocol import SetRemoteRegionBackendProtocol
from CommandCenter.models.set_remote_region_backend_protocol1 import SetRemoteRegionBackendProtocol1
from CommandCenter.models.set_remote_support_access import SetRemoteSupportAccess
from CommandCenter.models.set_scheduling_status import SetSchedulingStatus
from CommandCenter.models.set_snmp import SetSnmp
from CommandCenter.models.set_ticket_settings import SetTicketSettings
from CommandCenter.models.set_ticket_settings1 import SetTicketSettings1
from CommandCenter.models.set_vpsa_recycle_bin import SetVpsaRecycleBin
from CommandCenter.models.shutdown_storage_node import ShutdownStorageNode
from CommandCenter.models.sn_install import SnInstall
from CommandCenter.models.unreserve_vrid_from_vlan import UnreserveVridFromVlan
from CommandCenter.models.update_cloud_control_ip_whitelisting_entries import UpdateCloudControlIpWhitelistingEntries
from CommandCenter.models.update_endpoint import UpdateEndpoint
from CommandCenter.models.update_endpoints_config import UpdateEndpointsConfig
from CommandCenter.models.update_user import UpdateUser
from CommandCenter.models.update_vpsa_upload_endpoint import UpdateVpsaUploadEndpoint
from CommandCenter.models.update_zios_upload_endpoint import UpdateZiosUploadEndpoint
from CommandCenter.models.upgrade_cloud import UpgradeCloud
from CommandCenter.models.upgrade_sn import UpgradeSn
from CommandCenter.models.upgrade_sn_megaraid_and_drives_firmware import UpgradeSnMegaraidAndDrivesFirmware
from CommandCenter.models.upgrade_vpsa_version import UpgradeVpsaVersion
from CommandCenter.models.upgrade_zios import UpgradeZios
from CommandCenter.models.users_json_user import UsersJsonUser
from CommandCenter.models.volume import Volume
from CommandCenter.models.volume_drive import VolumeDrive
from CommandCenter.models.zsnap_storage_node import ZsnapStorageNode



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.vlan_api import VLANApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestVLANApi(unittest.TestCase):
    """VLANApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.vlan_api.VLANApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_provisioned_vlan_or_range(self):
        """Test case for add_provisioned_vlan_or_range

        """
        pass

    def test_allocate_vlan_to_cloud_user(self):
        """Test case for allocate_vlan_to_cloud_user

        """
        pass

    def test_deallocate_vlan_to_cloud_user(self):
        """Test case for deallocate_vlan_to_cloud_user

        """
        pass

    def test_delete_vlans(self):
        """Test case for delete_vlans

        """
        pass

    def test_delete_vrid_from_vlan(self):
        """Test case for delete_vrid_from_vlan

        """
        pass

    def test_get_vlans(self):
        """Test case for get_vlans

        """
        pass

    def test_populate_vrid_in_vlan(self):
        """Test case for populate_vrid_in_vlan

        """
        pass

    def test_reserve_provisioned_vlan(self):
        """Test case for reserve_provisioned_vlan

        """
        pass

    def test_reserve_vrid_for_vlan(self):
        """Test case for reserve_vrid_for_vlan

        """
        pass

    def test_set_default_vlan_for_cloud_user(self):
        """Test case for set_default_vlan_for_cloud_user

        """
        pass

    def test_unreserve_provisioned_vlan(self):
        """Test case for unreserve_provisioned_vlan

        """
        pass

    def test_unreserve_vrid_from_vlan(self):
        """Test case for unreserve_vrid_from_vlan

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse20021ResponseUsages(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cpu_user': 'float',
        'cpu_system': 'float',
        'cpu_iowait': 'float',
        'cpu_idle': 'float',
        'mem_alloc': 'float',
        'gb_wrt': 'float',
        'gb_rd': 'float',
        'zcache_data_dirty': 'float',
        'zcache_meta_dirty': 'float',
        'point': 'int'
    }

    attribute_map = {
        'cpu_user': 'cpu_user',
        'cpu_system': 'cpu_system',
        'cpu_iowait': 'cpu_iowait',
        'cpu_idle': 'cpu_idle',
        'mem_alloc': 'mem_alloc',
        'gb_wrt': 'gb_wrt',
        'gb_rd': 'gb_rd',
        'zcache_data_dirty': 'zcache_data_dirty',
        'zcache_meta_dirty': 'zcache_meta_dirty',
        'point': 'point'
    }

    def __init__(self, cpu_user=None, cpu_system=None, cpu_iowait=None, cpu_idle=None, mem_alloc=None, gb_wrt=None, gb_rd=None, zcache_data_dirty=None, zcache_meta_dirty=None, point=None, _configuration=None):  # noqa: E501
        """InlineResponse20021ResponseUsages - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cpu_user = None
        self._cpu_system = None
        self._cpu_iowait = None
        self._cpu_idle = None
        self._mem_alloc = None
        self._gb_wrt = None
        self._gb_rd = None
        self._zcache_data_dirty = None
        self._zcache_meta_dirty = None
        self._point = None
        self.discriminator = None

        if cpu_user is not None:
            self.cpu_user = cpu_user
        if cpu_system is not None:
            self.cpu_system = cpu_system
        if cpu_iowait is not None:
            self.cpu_iowait = cpu_iowait
        if cpu_idle is not None:
            self.cpu_idle = cpu_idle
        if mem_alloc is not None:
            self.mem_alloc = mem_alloc
        if gb_wrt is not None:
            self.gb_wrt = gb_wrt
        if gb_rd is not None:
            self.gb_rd = gb_rd
        if zcache_data_dirty is not None:
            self.zcache_data_dirty = zcache_data_dirty
        if zcache_meta_dirty is not None:
            self.zcache_meta_dirty = zcache_meta_dirty
        if point is not None:
            self.point = point

    @property
    def cpu_user(self):
        """Gets the cpu_user of this InlineResponse20021ResponseUsages.  # noqa: E501


        :return: The cpu_user of this InlineResponse20021ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._cpu_user

    @cpu_user.setter
    def cpu_user(self, cpu_user):
        """Sets the cpu_user of this InlineResponse20021ResponseUsages.


        :param cpu_user: The cpu_user of this InlineResponse20021ResponseUsages.  # noqa: E501
        :type: float
        """

        self._cpu_user = cpu_user

    @property
    def cpu_system(self):
        """Gets the cpu_system of this InlineResponse20021ResponseUsages.  # noqa: E501


        :return: The cpu_system of this InlineResponse20021ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._cpu_system

    @cpu_system.setter
    def cpu_system(self, cpu_system):
        """Sets the cpu_system of this InlineResponse20021ResponseUsages.


        :param cpu_system: The cpu_system of this InlineResponse20021ResponseUsages.  # noqa: E501
        :type: float
        """

        self._cpu_system = cpu_system

    @property
    def cpu_iowait(self):
        """Gets the cpu_iowait of this InlineResponse20021ResponseUsages.  # noqa: E501


        :return: The cpu_iowait of this InlineResponse20021ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._cpu_iowait

    @cpu_iowait.setter
    def cpu_iowait(self, cpu_iowait):
        """Sets the cpu_iowait of this InlineResponse20021ResponseUsages.


        :param cpu_iowait: The cpu_iowait of this InlineResponse20021ResponseUsages.  # noqa: E501
        :type: float
        """

        self._cpu_iowait = cpu_iowait

    @property
    def cpu_idle(self):
        """Gets the cpu_idle of this InlineResponse20021ResponseUsages.  # noqa: E501


        :return: The cpu_idle of this InlineResponse20021ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._cpu_idle

    @cpu_idle.setter
    def cpu_idle(self, cpu_idle):
        """Sets the cpu_idle of this InlineResponse20021ResponseUsages.


        :param cpu_idle: The cpu_idle of this InlineResponse20021ResponseUsages.  # noqa: E501
        :type: float
        """

        self._cpu_idle = cpu_idle

    @property
    def mem_alloc(self):
        """Gets the mem_alloc of this InlineResponse20021ResponseUsages.  # noqa: E501


        :return: The mem_alloc of this InlineResponse20021ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._mem_alloc

    @mem_alloc.setter
    def mem_alloc(self, mem_alloc):
        """Sets the mem_alloc of this InlineResponse20021ResponseUsages.


        :param mem_alloc: The mem_alloc of this InlineResponse20021ResponseUsages.  # noqa: E501
        :type: float
        """

        self._mem_alloc = mem_alloc

    @property
    def gb_wrt(self):
        """Gets the gb_wrt of this InlineResponse20021ResponseUsages.  # noqa: E501


        :return: The gb_wrt of this InlineResponse20021ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._gb_wrt

    @gb_wrt.setter
    def gb_wrt(self, gb_wrt):
        """Sets the gb_wrt of this InlineResponse20021ResponseUsages.


        :param gb_wrt: The gb_wrt of this InlineResponse20021ResponseUsages.  # noqa: E501
        :type: float
        """

        self._gb_wrt = gb_wrt

    @property
    def gb_rd(self):
        """Gets the gb_rd of this InlineResponse20021ResponseUsages.  # noqa: E501


        :return: The gb_rd of this InlineResponse20021ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._gb_rd

    @gb_rd.setter
    def gb_rd(self, gb_rd):
        """Sets the gb_rd of this InlineResponse20021ResponseUsages.


        :param gb_rd: The gb_rd of this InlineResponse20021ResponseUsages.  # noqa: E501
        :type: float
        """

        self._gb_rd = gb_rd

    @property
    def zcache_data_dirty(self):
        """Gets the zcache_data_dirty of this InlineResponse20021ResponseUsages.  # noqa: E501


        :return: The zcache_data_dirty of this InlineResponse20021ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._zcache_data_dirty

    @zcache_data_dirty.setter
    def zcache_data_dirty(self, zcache_data_dirty):
        """Sets the zcache_data_dirty of this InlineResponse20021ResponseUsages.


        :param zcache_data_dirty: The zcache_data_dirty of this InlineResponse20021ResponseUsages.  # noqa: E501
        :type: float
        """

        self._zcache_data_dirty = zcache_data_dirty

    @property
    def zcache_meta_dirty(self):
        """Gets the zcache_meta_dirty of this InlineResponse20021ResponseUsages.  # noqa: E501


        :return: The zcache_meta_dirty of this InlineResponse20021ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._zcache_meta_dirty

    @zcache_meta_dirty.setter
    def zcache_meta_dirty(self, zcache_meta_dirty):
        """Sets the zcache_meta_dirty of this InlineResponse20021ResponseUsages.


        :param zcache_meta_dirty: The zcache_meta_dirty of this InlineResponse20021ResponseUsages.  # noqa: E501
        :type: float
        """

        self._zcache_meta_dirty = zcache_meta_dirty

    @property
    def point(self):
        """Gets the point of this InlineResponse20021ResponseUsages.  # noqa: E501


        :return: The point of this InlineResponse20021ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._point

    @point.setter
    def point(self, point):
        """Sets the point of this InlineResponse20021ResponseUsages.


        :param point: The point of this InlineResponse20021ResponseUsages.  # noqa: E501
        :type: int
        """

        self._point = point

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20021ResponseUsages, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20021ResponseUsages):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20021ResponseUsages):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class InlineResponse2002ResponseAccount(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'update_time': 'str',
        'name': 'str',
        'is_system_account': 'str',
        'public_url_list': 'list[str]',
        'enabled': 'str',
        'email': 'str',
        'state': 'str',
        'create_time': 'str',
        'id': 'str',
        'description': 'str'
    }

    attribute_map = {
        'update_time': 'update_time',
        'name': 'name',
        'is_system_account': 'is_system_account',
        'public_url_list': 'public_url_list',
        'enabled': 'enabled',
        'email': 'email',
        'state': 'state',
        'create_time': 'create_time',
        'id': 'id',
        'description': 'description'
    }

    def __init__(self, update_time=None, name=None, is_system_account=None, public_url_list=None, enabled=None, email=None, state=None, create_time=None, id=None, description=None, _configuration=None):  # noqa: E501
        """InlineResponse2002ResponseAccount - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._update_time = None
        self._name = None
        self._is_system_account = None
        self._public_url_list = None
        self._enabled = None
        self._email = None
        self._state = None
        self._create_time = None
        self._id = None
        self._description = None
        self.discriminator = None

        if update_time is not None:
            self.update_time = update_time
        if name is not None:
            self.name = name
        if is_system_account is not None:
            self.is_system_account = is_system_account
        if public_url_list is not None:
            self.public_url_list = public_url_list
        if enabled is not None:
            self.enabled = enabled
        if email is not None:
            self.email = email
        if state is not None:
            self.state = state
        if create_time is not None:
            self.create_time = create_time
        if id is not None:
            self.id = id
        if description is not None:
            self.description = description

    @property
    def update_time(self):
        """Gets the update_time of this InlineResponse2002ResponseAccount.  # noqa: E501


        :return: The update_time of this InlineResponse2002ResponseAccount.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this InlineResponse2002ResponseAccount.


        :param update_time: The update_time of this InlineResponse2002ResponseAccount.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    @property
    def name(self):
        """Gets the name of this InlineResponse2002ResponseAccount.  # noqa: E501


        :return: The name of this InlineResponse2002ResponseAccount.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse2002ResponseAccount.


        :param name: The name of this InlineResponse2002ResponseAccount.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def is_system_account(self):
        """Gets the is_system_account of this InlineResponse2002ResponseAccount.  # noqa: E501


        :return: The is_system_account of this InlineResponse2002ResponseAccount.  # noqa: E501
        :rtype: str
        """
        return self._is_system_account

    @is_system_account.setter
    def is_system_account(self, is_system_account):
        """Sets the is_system_account of this InlineResponse2002ResponseAccount.


        :param is_system_account: The is_system_account of this InlineResponse2002ResponseAccount.  # noqa: E501
        :type: str
        """

        self._is_system_account = is_system_account

    @property
    def public_url_list(self):
        """Gets the public_url_list of this InlineResponse2002ResponseAccount.  # noqa: E501


        :return: The public_url_list of this InlineResponse2002ResponseAccount.  # noqa: E501
        :rtype: list[str]
        """
        return self._public_url_list

    @public_url_list.setter
    def public_url_list(self, public_url_list):
        """Sets the public_url_list of this InlineResponse2002ResponseAccount.


        :param public_url_list: The public_url_list of this InlineResponse2002ResponseAccount.  # noqa: E501
        :type: list[str]
        """

        self._public_url_list = public_url_list

    @property
    def enabled(self):
        """Gets the enabled of this InlineResponse2002ResponseAccount.  # noqa: E501


        :return: The enabled of this InlineResponse2002ResponseAccount.  # noqa: E501
        :rtype: str
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this InlineResponse2002ResponseAccount.


        :param enabled: The enabled of this InlineResponse2002ResponseAccount.  # noqa: E501
        :type: str
        """

        self._enabled = enabled

    @property
    def email(self):
        """Gets the email of this InlineResponse2002ResponseAccount.  # noqa: E501


        :return: The email of this InlineResponse2002ResponseAccount.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this InlineResponse2002ResponseAccount.


        :param email: The email of this InlineResponse2002ResponseAccount.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def state(self):
        """Gets the state of this InlineResponse2002ResponseAccount.  # noqa: E501


        :return: The state of this InlineResponse2002ResponseAccount.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this InlineResponse2002ResponseAccount.


        :param state: The state of this InlineResponse2002ResponseAccount.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def create_time(self):
        """Gets the create_time of this InlineResponse2002ResponseAccount.  # noqa: E501


        :return: The create_time of this InlineResponse2002ResponseAccount.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this InlineResponse2002ResponseAccount.


        :param create_time: The create_time of this InlineResponse2002ResponseAccount.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def id(self):
        """Gets the id of this InlineResponse2002ResponseAccount.  # noqa: E501


        :return: The id of this InlineResponse2002ResponseAccount.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse2002ResponseAccount.


        :param id: The id of this InlineResponse2002ResponseAccount.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def description(self):
        """Gets the description of this InlineResponse2002ResponseAccount.  # noqa: E501


        :return: The description of this InlineResponse2002ResponseAccount.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this InlineResponse2002ResponseAccount.


        :param description: The description of this InlineResponse2002ResponseAccount.  # noqa: E501
        :type: str
        """

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse2002ResponseAccount, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse2002ResponseAccount):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse2002ResponseAccount):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class CreateComputeAccount(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'provider_id': 'int',
        'display_name': 'str',
        'display_description': 'str',
        'cores': 'int',
        'ram': 'int',
        'instances': 'int',
        'moderate': 'bool'
    }

    attribute_map = {
        'provider_id': 'provider_id',
        'display_name': 'display_name',
        'display_description': 'display_description',
        'cores': 'cores',
        'ram': 'ram',
        'instances': 'instances',
        'moderate': 'moderate'
    }

    def __init__(self, provider_id=None, display_name=None, display_description=None, cores=None, ram=None, instances=None, moderate=None, _configuration=None):  # noqa: E501
        """CreateComputeAccount - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._provider_id = None
        self._display_name = None
        self._display_description = None
        self._cores = None
        self._ram = None
        self._instances = None
        self._moderate = None
        self.discriminator = None

        self.provider_id = provider_id
        self.display_name = display_name
        if display_description is not None:
            self.display_description = display_description
        if cores is not None:
            self.cores = cores
        if ram is not None:
            self.ram = ram
        if instances is not None:
            self.instances = instances
        if moderate is not None:
            self.moderate = moderate

    @property
    def provider_id(self):
        """Gets the provider_id of this CreateComputeAccount.  # noqa: E501

        Your Cloud provider's id.  # noqa: E501

        :return: The provider_id of this CreateComputeAccount.  # noqa: E501
        :rtype: int
        """
        return self._provider_id

    @provider_id.setter
    def provider_id(self, provider_id):
        """Sets the provider_id of this CreateComputeAccount.

        Your Cloud provider's id.  # noqa: E501

        :param provider_id: The provider_id of this CreateComputeAccount.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and provider_id is None:
            raise ValueError("Invalid value for `provider_id`, must not be `None`")  # noqa: E501

        self._provider_id = provider_id

    @property
    def display_name(self):
        """Gets the display_name of this CreateComputeAccount.  # noqa: E501

        Compute Account Name.  # noqa: E501

        :return: The display_name of this CreateComputeAccount.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this CreateComputeAccount.

        Compute Account Name.  # noqa: E501

        :param display_name: The display_name of this CreateComputeAccount.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and display_name is None:
            raise ValueError("Invalid value for `display_name`, must not be `None`")  # noqa: E501

        self._display_name = display_name

    @property
    def display_description(self):
        """Gets the display_description of this CreateComputeAccount.  # noqa: E501

        Compute Account Description.  # noqa: E501

        :return: The display_description of this CreateComputeAccount.  # noqa: E501
        :rtype: str
        """
        return self._display_description

    @display_description.setter
    def display_description(self, display_description):
        """Sets the display_description of this CreateComputeAccount.

        Compute Account Description.  # noqa: E501

        :param display_description: The display_description of this CreateComputeAccount.  # noqa: E501
        :type: str
        """

        self._display_description = display_description

    @property
    def cores(self):
        """Gets the cores of this CreateComputeAccount.  # noqa: E501

        CPU cores limit.  # noqa: E501

        :return: The cores of this CreateComputeAccount.  # noqa: E501
        :rtype: int
        """
        return self._cores

    @cores.setter
    def cores(self, cores):
        """Sets the cores of this CreateComputeAccount.

        CPU cores limit.  # noqa: E501

        :param cores: The cores of this CreateComputeAccount.  # noqa: E501
        :type: int
        """

        self._cores = cores

    @property
    def ram(self):
        """Gets the ram of this CreateComputeAccount.  # noqa: E501

        RAM limit.  # noqa: E501

        :return: The ram of this CreateComputeAccount.  # noqa: E501
        :rtype: int
        """
        return self._ram

    @ram.setter
    def ram(self, ram):
        """Sets the ram of this CreateComputeAccount.

        RAM limit.  # noqa: E501

        :param ram: The ram of this CreateComputeAccount.  # noqa: E501
        :type: int
        """

        self._ram = ram

    @property
    def instances(self):
        """Gets the instances of this CreateComputeAccount.  # noqa: E501

        Instances limit.  # noqa: E501

        :return: The instances of this CreateComputeAccount.  # noqa: E501
        :rtype: int
        """
        return self._instances

    @instances.setter
    def instances(self, instances):
        """Sets the instances of this CreateComputeAccount.

        Instances limit.  # noqa: E501

        :param instances: The instances of this CreateComputeAccount.  # noqa: E501
        :type: int
        """

        self._instances = instances

    @property
    def moderate(self):
        """Gets the moderate of this CreateComputeAccount.  # noqa: E501


        :return: The moderate of this CreateComputeAccount.  # noqa: E501
        :rtype: bool
        """
        return self._moderate

    @moderate.setter
    def moderate(self, moderate):
        """Sets the moderate of this CreateComputeAccount.


        :param moderate: The moderate of this CreateComputeAccount.  # noqa: E501
        :type: bool
        """

        self._moderate = moderate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateComputeAccount, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateComputeAccount):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateComputeAccount):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from CommandCenter.api_client import ApiClient


class CloudUsersApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def allocate_vlan(self, cloud_name, tenant_id, allocate_vlan, **kwargs):  # noqa: E501
        """allocate_vlan  # noqa: E501

        Allocate vlan for cloud user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.allocate_vlan(cloud_name, tenant_id, allocate_vlan, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str tenant_id: (required)
        :param AllocateVlan allocate_vlan: (required)
        :return: InlineResponse20011
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.allocate_vlan_with_http_info(cloud_name, tenant_id, allocate_vlan, **kwargs)  # noqa: E501
        else:
            (data) = self.allocate_vlan_with_http_info(cloud_name, tenant_id, allocate_vlan, **kwargs)  # noqa: E501
            return data

    def allocate_vlan_with_http_info(self, cloud_name, tenant_id, allocate_vlan, **kwargs):  # noqa: E501
        """allocate_vlan  # noqa: E501

        Allocate vlan for cloud user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.allocate_vlan_with_http_info(cloud_name, tenant_id, allocate_vlan, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str tenant_id: (required)
        :param AllocateVlan allocate_vlan: (required)
        :return: InlineResponse20011
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'tenant_id', 'allocate_vlan']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method allocate_vlan" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `allocate_vlan`")  # noqa: E501
        # verify the required parameter 'tenant_id' is set
        if self.api_client.client_side_validation and ('tenant_id' not in params or
                                                       params['tenant_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `tenant_id` when calling `allocate_vlan`")  # noqa: E501
        # verify the required parameter 'allocate_vlan' is set
        if self.api_client.client_side_validation and ('allocate_vlan' not in params or
                                                       params['allocate_vlan'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `allocate_vlan` when calling `allocate_vlan`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'tenant_id' in params:
            path_params['tenant_id'] = params['tenant_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'allocate_vlan' in params:
            body_params = params['allocate_vlan']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/cloud_users/{tenant_id}/allocate_vlan_id.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20011',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_tenant(self, cloud_name, tenant_id, delete_tenant, **kwargs):  # noqa: E501
        """delete_tenant  # noqa: E501

        Deallocate vlan for cloud user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_tenant(cloud_name, tenant_id, delete_tenant, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str tenant_id: (required)
        :param DeleteTenant delete_tenant: (required)
        :return: InlineResponse20012
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_tenant_with_http_info(cloud_name, tenant_id, delete_tenant, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_tenant_with_http_info(cloud_name, tenant_id, delete_tenant, **kwargs)  # noqa: E501
            return data

    def delete_tenant_with_http_info(self, cloud_name, tenant_id, delete_tenant, **kwargs):  # noqa: E501
        """delete_tenant  # noqa: E501

        Deallocate vlan for cloud user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_tenant_with_http_info(cloud_name, tenant_id, delete_tenant, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str tenant_id: (required)
        :param DeleteTenant delete_tenant: (required)
        :return: InlineResponse20012
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'tenant_id', 'delete_tenant']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_tenant" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `delete_tenant`")  # noqa: E501
        # verify the required parameter 'tenant_id' is set
        if self.api_client.client_side_validation and ('tenant_id' not in params or
                                                       params['tenant_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `tenant_id` when calling `delete_tenant`")  # noqa: E501
        # verify the required parameter 'delete_tenant' is set
        if self.api_client.client_side_validation and ('delete_tenant' not in params or
                                                       params['delete_tenant'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `delete_tenant` when calling `delete_tenant`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'tenant_id' in params:
            path_params['tenant_id'] = params['tenant_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'delete_tenant' in params:
            body_params = params['delete_tenant']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/cloud_users/{tenant_id}/deallocate_vlan_id.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20012',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_tenant(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_tenant  # noqa: E501

        Returns the details for a singe Cloud user (tenant).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_tenant(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2008
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_tenant_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_tenant_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def get_tenant_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_tenant  # noqa: E501

        Returns the details for a singe Cloud user (tenant).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_tenant_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2008
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_tenant" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `get_tenant`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_tenant`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/cloud_users/{id}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2008',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_tenants(self, cloud_name, **kwargs):  # noqa: E501
        """get_tenants  # noqa: E501

        Returns a list of all the users (tenants) in a Cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_tenants(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param int page: The page number to start from.
        :param int per_page: The total number of records to return.
        :return: InlineResponse2007
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_tenants_with_http_info(cloud_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_tenants_with_http_info(cloud_name, **kwargs)  # noqa: E501
            return data

    def get_tenants_with_http_info(self, cloud_name, **kwargs):  # noqa: E501
        """get_tenants  # noqa: E501

        Returns a list of all the users (tenants) in a Cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_tenants_with_http_info(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param int page: The page number to start from.
        :param int per_page: The total number of records to return.
        :return: InlineResponse2007
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'page', 'per_page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_tenants" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `get_tenants`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'per_page' in params:
            query_params.append(('per_page', params['per_page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/cloud_users.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2007',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_cloud_user_comments(self, cloud_name, id, **kwargs):  # noqa: E501
        """list_cloud_user_comments  # noqa: E501

        Returns the list of the cloud_user comments.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_cloud_user_comments(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20010
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_cloud_user_comments_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_cloud_user_comments_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def list_cloud_user_comments_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """list_cloud_user_comments  # noqa: E501

        Returns the list of the cloud_user comments.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_cloud_user_comments_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20010
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_cloud_user_comments" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `list_cloud_user_comments`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `list_cloud_user_comments`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/cloud_users/{id}/comments.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20010',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_cloud_vlans(self, cloud_name, **kwargs):  # noqa: E501
        """list_cloud_vlans  # noqa: E501

        Returns the vlans for the cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_cloud_vlans(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :return: InlineResponse2009
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_cloud_vlans_with_http_info(cloud_name, **kwargs)  # noqa: E501
        else:
            (data) = self.list_cloud_vlans_with_http_info(cloud_name, **kwargs)  # noqa: E501
            return data

    def list_cloud_vlans_with_http_info(self, cloud_name, **kwargs):  # noqa: E501
        """list_cloud_vlans  # noqa: E501

        Returns the vlans for the cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_cloud_vlans_with_http_info(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :return: InlineResponse2009
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_cloud_vlans" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `list_cloud_vlans`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/cloud_users/vlans.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2009',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from Vpsa.api.consistency_groups_api import ConsistencyGroupsApi
from Vpsa.api.containers_api import ContainersApi
from Vpsa.api.controllers_api import ControllersApi
from Vpsa.api.drives_api import DrivesApi
from Vpsa.api.file_lifecycle_api import FileLifecycleApi
from Vpsa.api.file_lifecycle_policies_api import FileLifecyclePoliciesApi
from Vpsa.api.images_api import ImagesApi
from Vpsa.api.logs_api import LogsApi
from Vpsa.api.mirroring_and_cloning_api import MirroringAndCloningApi
from Vpsa.api.nas_api import NASApi
from Vpsa.api.pools_api import PoolsApi
from Vpsa.api.raid_groups_api import RAIDGroupsApi
from Vpsa.api.remote_object_storage_api import RemoteObjectStorageApi
from Vpsa.api.roles_api import RolesApi
from Vpsa.api.servers_api import ServersApi
from Vpsa.api.settings_api import SettingsApi
from Vpsa.api.snapshot_policies_api import SnapshotPoliciesApi
from Vpsa.api.tickets_api import TicketsApi
from Vpsa.api.users_api import UsersApi
from Vpsa.api.volumes_api import VolumesApi
from Vpsa.api.vpsas_api import VpsasApi



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class UpdateServer(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'force': 'str',
        'display_name': 'str',
        'os': 'str',
        'vpsachapuser': 'str',
        'vpsachapsecret': 'str',
        'hostchapuser': 'str',
        'hostchapsecret': 'str',
        'iqn': 'str',
        'iscsi': 'str',
        'ipsec_iscsi': 'str',
        'ipsec_nfs': 'str',
        'monitoring': 'str',
        'remove_wwpns': 'list[str]',
        'add_wwpns': 'list[str]'
    }

    attribute_map = {
        'force': 'force',
        'display_name': 'display_name',
        'os': 'os',
        'vpsachapuser': 'vpsachapuser',
        'vpsachapsecret': 'vpsachapsecret',
        'hostchapuser': 'hostchapuser',
        'hostchapsecret': 'hostchapsecret',
        'iqn': 'iqn',
        'iscsi': 'iscsi',
        'ipsec_iscsi': 'ipsec_iscsi',
        'ipsec_nfs': 'ipsec_nfs',
        'monitoring': 'monitoring',
        'remove_wwpns': 'remove_wwpns',
        'add_wwpns': 'add_wwpns'
    }

    def __init__(self, force=None, display_name=None, os=None, vpsachapuser=None, vpsachapsecret=None, hostchapuser=None, hostchapsecret=None, iqn=None, iscsi=None, ipsec_iscsi=None, ipsec_nfs=None, monitoring=None, remove_wwpns=None, add_wwpns=None, _configuration=None):  # noqa: E501
        """UpdateServer - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._force = None
        self._display_name = None
        self._os = None
        self._vpsachapuser = None
        self._vpsachapsecret = None
        self._hostchapuser = None
        self._hostchapsecret = None
        self._iqn = None
        self._iscsi = None
        self._ipsec_iscsi = None
        self._ipsec_nfs = None
        self._monitoring = None
        self._remove_wwpns = None
        self._add_wwpns = None
        self.discriminator = None

        if force is not None:
            self.force = force
        if display_name is not None:
            self.display_name = display_name
        if os is not None:
            self.os = os
        if vpsachapuser is not None:
            self.vpsachapuser = vpsachapuser
        if vpsachapsecret is not None:
            self.vpsachapsecret = vpsachapsecret
        if hostchapuser is not None:
            self.hostchapuser = hostchapuser
        if hostchapsecret is not None:
            self.hostchapsecret = hostchapsecret
        if iqn is not None:
            self.iqn = iqn
        if iscsi is not None:
            self.iscsi = iscsi
        if ipsec_iscsi is not None:
            self.ipsec_iscsi = ipsec_iscsi
        if ipsec_nfs is not None:
            self.ipsec_nfs = ipsec_nfs
        if monitoring is not None:
            self.monitoring = monitoring
        if remove_wwpns is not None:
            self.remove_wwpns = remove_wwpns
        if add_wwpns is not None:
            self.add_wwpns = add_wwpns

    @property
    def force(self):
        """Gets the force of this UpdateServer.  # noqa: E501


        :return: The force of this UpdateServer.  # noqa: E501
        :rtype: str
        """
        return self._force

    @force.setter
    def force(self, force):
        """Sets the force of this UpdateServer.


        :param force: The force of this UpdateServer.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                force not in allowed_values):
            raise ValueError(
                "Invalid value for `force` ({0}), must be one of {1}"  # noqa: E501
                .format(force, allowed_values)
            )

        self._force = force

    @property
    def display_name(self):
        """Gets the display_name of this UpdateServer.  # noqa: E501

        The server display name  # noqa: E501

        :return: The display_name of this UpdateServer.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this UpdateServer.

        The server display name  # noqa: E501

        :param display_name: The display_name of this UpdateServer.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def os(self):
        """Gets the os of this UpdateServer.  # noqa: E501

        Server's OS  # noqa: E501

        :return: The os of this UpdateServer.  # noqa: E501
        :rtype: str
        """
        return self._os

    @os.setter
    def os(self, os):
        """Sets the os of this UpdateServer.

        Server's OS  # noqa: E501

        :param os: The os of this UpdateServer.  # noqa: E501
        :type: str
        """
        allowed_values = ["Windows", "Linux", "Solaris", "AIX", "ESXi"]  # noqa: E501
        if (self._configuration.client_side_validation and
                os not in allowed_values):
            raise ValueError(
                "Invalid value for `os` ({0}), must be one of {1}"  # noqa: E501
                .format(os, allowed_values)
            )

        self._os = os

    @property
    def vpsachapuser(self):
        """Gets the vpsachapuser of this UpdateServer.  # noqa: E501

        VPSA chap user.  # noqa: E501

        :return: The vpsachapuser of this UpdateServer.  # noqa: E501
        :rtype: str
        """
        return self._vpsachapuser

    @vpsachapuser.setter
    def vpsachapuser(self, vpsachapuser):
        """Sets the vpsachapuser of this UpdateServer.

        VPSA chap user.  # noqa: E501

        :param vpsachapuser: The vpsachapuser of this UpdateServer.  # noqa: E501
        :type: str
        """

        self._vpsachapuser = vpsachapuser

    @property
    def vpsachapsecret(self):
        """Gets the vpsachapsecret of this UpdateServer.  # noqa: E501

        VPSA chap secret. 12-16 characters.  # noqa: E501

        :return: The vpsachapsecret of this UpdateServer.  # noqa: E501
        :rtype: str
        """
        return self._vpsachapsecret

    @vpsachapsecret.setter
    def vpsachapsecret(self, vpsachapsecret):
        """Sets the vpsachapsecret of this UpdateServer.

        VPSA chap secret. 12-16 characters.  # noqa: E501

        :param vpsachapsecret: The vpsachapsecret of this UpdateServer.  # noqa: E501
        :type: str
        """

        self._vpsachapsecret = vpsachapsecret

    @property
    def hostchapuser(self):
        """Gets the hostchapuser of this UpdateServer.  # noqa: E501

        Host chap user.  # noqa: E501

        :return: The hostchapuser of this UpdateServer.  # noqa: E501
        :rtype: str
        """
        return self._hostchapuser

    @hostchapuser.setter
    def hostchapuser(self, hostchapuser):
        """Sets the hostchapuser of this UpdateServer.

        Host chap user.  # noqa: E501

        :param hostchapuser: The hostchapuser of this UpdateServer.  # noqa: E501
        :type: str
        """

        self._hostchapuser = hostchapuser

    @property
    def hostchapsecret(self):
        """Gets the hostchapsecret of this UpdateServer.  # noqa: E501

        Host chap secret. 12-16 characters.  # noqa: E501

        :return: The hostchapsecret of this UpdateServer.  # noqa: E501
        :rtype: str
        """
        return self._hostchapsecret

    @hostchapsecret.setter
    def hostchapsecret(self, hostchapsecret):
        """Sets the hostchapsecret of this UpdateServer.

        Host chap secret. 12-16 characters.  # noqa: E501

        :param hostchapsecret: The hostchapsecret of this UpdateServer.  # noqa: E501
        :type: str
        """

        self._hostchapsecret = hostchapsecret

    @property
    def iqn(self):
        """Gets the iqn of this UpdateServer.  # noqa: E501


        :return: The iqn of this UpdateServer.  # noqa: E501
        :rtype: str
        """
        return self._iqn

    @iqn.setter
    def iqn(self, iqn):
        """Sets the iqn of this UpdateServer.


        :param iqn: The iqn of this UpdateServer.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                iqn is not None and not re.search(r'^(?:iqn\\.[0-9]{4}-[0-9]{2}(?:\\.[A-Za-z](?:[A-Za-z0-9\\-]*[A-Za-z0-9])?)+(?::.*)?|eui\\.[0-9A-Fa_f]{16})\'', iqn)):  # noqa: E501
            raise ValueError(r"Invalid value for `iqn`, must be a follow pattern or equal to `/^(?:iqn\\.[0-9]{4}-[0-9]{2}(?:\\.[A-Za-z](?:[A-Za-z0-9\\-]*[A-Za-z0-9])?)+(?::.*)?|eui\\.[0-9A-Fa_f]{16})'/`")  # noqa: E501

        self._iqn = iqn

    @property
    def iscsi(self):
        """Gets the iscsi of this UpdateServer.  # noqa: E501

        The server's iSCSI IP  # noqa: E501

        :return: The iscsi of this UpdateServer.  # noqa: E501
        :rtype: str
        """
        return self._iscsi

    @iscsi.setter
    def iscsi(self, iscsi):
        """Sets the iscsi of this UpdateServer.

        The server's iSCSI IP  # noqa: E501

        :param iscsi: The iscsi of this UpdateServer.  # noqa: E501
        :type: str
        """

        self._iscsi = iscsi

    @property
    def ipsec_iscsi(self):
        """Gets the ipsec_iscsi of this UpdateServer.  # noqa: E501


        :return: The ipsec_iscsi of this UpdateServer.  # noqa: E501
        :rtype: str
        """
        return self._ipsec_iscsi

    @ipsec_iscsi.setter
    def ipsec_iscsi(self, ipsec_iscsi):
        """Sets the ipsec_iscsi of this UpdateServer.


        :param ipsec_iscsi: The ipsec_iscsi of this UpdateServer.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                ipsec_iscsi not in allowed_values):
            raise ValueError(
                "Invalid value for `ipsec_iscsi` ({0}), must be one of {1}"  # noqa: E501
                .format(ipsec_iscsi, allowed_values)
            )

        self._ipsec_iscsi = ipsec_iscsi

    @property
    def ipsec_nfs(self):
        """Gets the ipsec_nfs of this UpdateServer.  # noqa: E501


        :return: The ipsec_nfs of this UpdateServer.  # noqa: E501
        :rtype: str
        """
        return self._ipsec_nfs

    @ipsec_nfs.setter
    def ipsec_nfs(self, ipsec_nfs):
        """Sets the ipsec_nfs of this UpdateServer.


        :param ipsec_nfs: The ipsec_nfs of this UpdateServer.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                ipsec_nfs not in allowed_values):
            raise ValueError(
                "Invalid value for `ipsec_nfs` ({0}), must be one of {1}"  # noqa: E501
                .format(ipsec_nfs, allowed_values)
            )

        self._ipsec_nfs = ipsec_nfs

    @property
    def monitoring(self):
        """Gets the monitoring of this UpdateServer.  # noqa: E501

        connectivity monitoring  # noqa: E501

        :return: The monitoring of this UpdateServer.  # noqa: E501
        :rtype: str
        """
        return self._monitoring

    @monitoring.setter
    def monitoring(self, monitoring):
        """Sets the monitoring of this UpdateServer.

        connectivity monitoring  # noqa: E501

        :param monitoring: The monitoring of this UpdateServer.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                monitoring not in allowed_values):
            raise ValueError(
                "Invalid value for `monitoring` ({0}), must be one of {1}"  # noqa: E501
                .format(monitoring, allowed_values)
            )

        self._monitoring = monitoring

    @property
    def remove_wwpns(self):
        """Gets the remove_wwpns of this UpdateServer.  # noqa: E501

        wwpns to remove  # noqa: E501

        :return: The remove_wwpns of this UpdateServer.  # noqa: E501
        :rtype: list[str]
        """
        return self._remove_wwpns

    @remove_wwpns.setter
    def remove_wwpns(self, remove_wwpns):
        """Sets the remove_wwpns of this UpdateServer.

        wwpns to remove  # noqa: E501

        :param remove_wwpns: The remove_wwpns of this UpdateServer.  # noqa: E501
        :type: list[str]
        """

        self._remove_wwpns = remove_wwpns

    @property
    def add_wwpns(self):
        """Gets the add_wwpns of this UpdateServer.  # noqa: E501

        wwpns to add  # noqa: E501

        :return: The add_wwpns of this UpdateServer.  # noqa: E501
        :rtype: list[str]
        """
        return self._add_wwpns

    @add_wwpns.setter
    def add_wwpns(self, add_wwpns):
        """Sets the add_wwpns of this UpdateServer.

        wwpns to add  # noqa: E501

        :param add_wwpns: The add_wwpns of this UpdateServer.  # noqa: E501
        :type: list[str]
        """

        self._add_wwpns = add_wwpns

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateServer, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateServer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateServer):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse2006ResponseContainers(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'image_name': 'str',
        'image_display_name': 'str',
        'image_id': 'int',
        'memory_pool_name': 'str',
        'memory_pool_display_name': 'str',
        'status': 'str',
        'entrypoint': 'str',
        'ip': 'str',
        'udp': 'str',
        'use_public_ip': 'int',
        'docker_id': 'str',
        'play_mode': 'int',
        'server_id': 'int',
        'exit_code': 'int',
        'created_at': 'str',
        'modified_at': 'str',
        'started_at': 'str',
        'exit_at': 'str',
        'ports': 'list[str]',
        'volumes': 'list[InlineResponse2006ResponseVolumes]',
        'envvars': 'list[str]',
        'args': 'list[str]'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'image_name': 'image_name',
        'image_display_name': 'image_display_name',
        'image_id': 'image_id',
        'memory_pool_name': 'memory_pool_name',
        'memory_pool_display_name': 'memory_pool_display_name',
        'status': 'status',
        'entrypoint': 'entrypoint',
        'ip': 'ip',
        'udp': 'udp',
        'use_public_ip': 'use_public_ip',
        'docker_id': 'docker_id',
        'play_mode': 'play_mode',
        'server_id': 'server_id',
        'exit_code': 'exit_code',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'started_at': 'started_at',
        'exit_at': 'exit_at',
        'ports': 'ports',
        'volumes': 'volumes',
        'envvars': 'envvars',
        'args': 'args'
    }

    def __init__(self, name=None, display_name=None, image_name=None, image_display_name=None, image_id=None, memory_pool_name=None, memory_pool_display_name=None, status=None, entrypoint=None, ip=None, udp=None, use_public_ip=None, docker_id=None, play_mode=None, server_id=None, exit_code=None, created_at=None, modified_at=None, started_at=None, exit_at=None, ports=None, volumes=None, envvars=None, args=None, _configuration=None):  # noqa: E501
        """InlineResponse2006ResponseContainers - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._image_name = None
        self._image_display_name = None
        self._image_id = None
        self._memory_pool_name = None
        self._memory_pool_display_name = None
        self._status = None
        self._entrypoint = None
        self._ip = None
        self._udp = None
        self._use_public_ip = None
        self._docker_id = None
        self._play_mode = None
        self._server_id = None
        self._exit_code = None
        self._created_at = None
        self._modified_at = None
        self._started_at = None
        self._exit_at = None
        self._ports = None
        self._volumes = None
        self._envvars = None
        self._args = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if image_name is not None:
            self.image_name = image_name
        if image_display_name is not None:
            self.image_display_name = image_display_name
        if image_id is not None:
            self.image_id = image_id
        if memory_pool_name is not None:
            self.memory_pool_name = memory_pool_name
        if memory_pool_display_name is not None:
            self.memory_pool_display_name = memory_pool_display_name
        if status is not None:
            self.status = status
        if entrypoint is not None:
            self.entrypoint = entrypoint
        if ip is not None:
            self.ip = ip
        if udp is not None:
            self.udp = udp
        if use_public_ip is not None:
            self.use_public_ip = use_public_ip
        if docker_id is not None:
            self.docker_id = docker_id
        if play_mode is not None:
            self.play_mode = play_mode
        if server_id is not None:
            self.server_id = server_id
        if exit_code is not None:
            self.exit_code = exit_code
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if started_at is not None:
            self.started_at = started_at
        if exit_at is not None:
            self.exit_at = exit_at
        if ports is not None:
            self.ports = ports
        if volumes is not None:
            self.volumes = volumes
        if envvars is not None:
            self.envvars = envvars
        if args is not None:
            self.args = args

    @property
    def name(self):
        """Gets the name of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The name of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse2006ResponseContainers.


        :param name: The name of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The display_name of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse2006ResponseContainers.


        :param display_name: The display_name of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def image_name(self):
        """Gets the image_name of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The image_name of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: str
        """
        return self._image_name

    @image_name.setter
    def image_name(self, image_name):
        """Sets the image_name of this InlineResponse2006ResponseContainers.


        :param image_name: The image_name of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: str
        """

        self._image_name = image_name

    @property
    def image_display_name(self):
        """Gets the image_display_name of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The image_display_name of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: str
        """
        return self._image_display_name

    @image_display_name.setter
    def image_display_name(self, image_display_name):
        """Sets the image_display_name of this InlineResponse2006ResponseContainers.


        :param image_display_name: The image_display_name of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: str
        """

        self._image_display_name = image_display_name

    @property
    def image_id(self):
        """Gets the image_id of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The image_id of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: int
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """Sets the image_id of this InlineResponse2006ResponseContainers.


        :param image_id: The image_id of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: int
        """

        self._image_id = image_id

    @property
    def memory_pool_name(self):
        """Gets the memory_pool_name of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The memory_pool_name of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: str
        """
        return self._memory_pool_name

    @memory_pool_name.setter
    def memory_pool_name(self, memory_pool_name):
        """Sets the memory_pool_name of this InlineResponse2006ResponseContainers.


        :param memory_pool_name: The memory_pool_name of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: str
        """

        self._memory_pool_name = memory_pool_name

    @property
    def memory_pool_display_name(self):
        """Gets the memory_pool_display_name of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The memory_pool_display_name of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: str
        """
        return self._memory_pool_display_name

    @memory_pool_display_name.setter
    def memory_pool_display_name(self, memory_pool_display_name):
        """Sets the memory_pool_display_name of this InlineResponse2006ResponseContainers.


        :param memory_pool_display_name: The memory_pool_display_name of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: str
        """

        self._memory_pool_display_name = memory_pool_display_name

    @property
    def status(self):
        """Gets the status of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The status of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse2006ResponseContainers.


        :param status: The status of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def entrypoint(self):
        """Gets the entrypoint of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The entrypoint of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: str
        """
        return self._entrypoint

    @entrypoint.setter
    def entrypoint(self, entrypoint):
        """Sets the entrypoint of this InlineResponse2006ResponseContainers.


        :param entrypoint: The entrypoint of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: str
        """

        self._entrypoint = entrypoint

    @property
    def ip(self):
        """Gets the ip of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The ip of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this InlineResponse2006ResponseContainers.


        :param ip: The ip of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: str
        """

        self._ip = ip

    @property
    def udp(self):
        """Gets the udp of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The udp of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: str
        """
        return self._udp

    @udp.setter
    def udp(self, udp):
        """Sets the udp of this InlineResponse2006ResponseContainers.


        :param udp: The udp of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: str
        """

        self._udp = udp

    @property
    def use_public_ip(self):
        """Gets the use_public_ip of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The use_public_ip of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: int
        """
        return self._use_public_ip

    @use_public_ip.setter
    def use_public_ip(self, use_public_ip):
        """Sets the use_public_ip of this InlineResponse2006ResponseContainers.


        :param use_public_ip: The use_public_ip of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: int
        """

        self._use_public_ip = use_public_ip

    @property
    def docker_id(self):
        """Gets the docker_id of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The docker_id of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: str
        """
        return self._docker_id

    @docker_id.setter
    def docker_id(self, docker_id):
        """Sets the docker_id of this InlineResponse2006ResponseContainers.


        :param docker_id: The docker_id of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: str
        """

        self._docker_id = docker_id

    @property
    def play_mode(self):
        """Gets the play_mode of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The play_mode of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: int
        """
        return self._play_mode

    @play_mode.setter
    def play_mode(self, play_mode):
        """Sets the play_mode of this InlineResponse2006ResponseContainers.


        :param play_mode: The play_mode of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: int
        """

        self._play_mode = play_mode

    @property
    def server_id(self):
        """Gets the server_id of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The server_id of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: int
        """
        return self._server_id

    @server_id.setter
    def server_id(self, server_id):
        """Sets the server_id of this InlineResponse2006ResponseContainers.


        :param server_id: The server_id of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: int
        """

        self._server_id = server_id

    @property
    def exit_code(self):
        """Gets the exit_code of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The exit_code of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: int
        """
        return self._exit_code

    @exit_code.setter
    def exit_code(self, exit_code):
        """Sets the exit_code of this InlineResponse2006ResponseContainers.


        :param exit_code: The exit_code of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: int
        """

        self._exit_code = exit_code

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The created_at of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse2006ResponseContainers.


        :param created_at: The created_at of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The modified_at of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse2006ResponseContainers.


        :param modified_at: The modified_at of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def started_at(self):
        """Gets the started_at of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The started_at of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: str
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this InlineResponse2006ResponseContainers.


        :param started_at: The started_at of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: str
        """

        self._started_at = started_at

    @property
    def exit_at(self):
        """Gets the exit_at of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The exit_at of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: str
        """
        return self._exit_at

    @exit_at.setter
    def exit_at(self, exit_at):
        """Sets the exit_at of this InlineResponse2006ResponseContainers.


        :param exit_at: The exit_at of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: str
        """

        self._exit_at = exit_at

    @property
    def ports(self):
        """Gets the ports of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The ports of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: list[str]
        """
        return self._ports

    @ports.setter
    def ports(self, ports):
        """Sets the ports of this InlineResponse2006ResponseContainers.


        :param ports: The ports of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: list[str]
        """

        self._ports = ports

    @property
    def volumes(self):
        """Gets the volumes of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The volumes of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: list[InlineResponse2006ResponseVolumes]
        """
        return self._volumes

    @volumes.setter
    def volumes(self, volumes):
        """Sets the volumes of this InlineResponse2006ResponseContainers.


        :param volumes: The volumes of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: list[InlineResponse2006ResponseVolumes]
        """

        self._volumes = volumes

    @property
    def envvars(self):
        """Gets the envvars of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The envvars of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: list[str]
        """
        return self._envvars

    @envvars.setter
    def envvars(self, envvars):
        """Sets the envvars of this InlineResponse2006ResponseContainers.


        :param envvars: The envvars of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: list[str]
        """

        self._envvars = envvars

    @property
    def args(self):
        """Gets the args of this InlineResponse2006ResponseContainers.  # noqa: E501


        :return: The args of this InlineResponse2006ResponseContainers.  # noqa: E501
        :rtype: list[str]
        """
        return self._args

    @args.setter
    def args(self, args):
        """Sets the args of this InlineResponse2006ResponseContainers.


        :param args: The args of this InlineResponse2006ResponseContainers.  # noqa: E501
        :type: list[str]
        """

        self._args = args

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse2006ResponseContainers, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse2006ResponseContainers):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse2006ResponseContainers):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class CreateRosRestoreJob(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'mode': 'str',
        'poolname': 'str',
        'volname': 'str',
        'remote_object_store': 'str',
        'key': 'str',
        'local_snapname': 'str',
        'crypt': 'str',
        'dedupe': 'str',
        'compress': 'str'
    }

    attribute_map = {
        'name': 'name',
        'mode': 'mode',
        'poolname': 'poolname',
        'volname': 'volname',
        'remote_object_store': 'remote_object_store',
        'key': 'key',
        'local_snapname': 'local_snapname',
        'crypt': 'crypt',
        'dedupe': 'dedupe',
        'compress': 'compress'
    }

    def __init__(self, name=None, mode=None, poolname=None, volname=None, remote_object_store=None, key=None, local_snapname=None, crypt=None, dedupe=None, compress=None, _configuration=None):  # noqa: E501
        """CreateRosRestoreJob - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._mode = None
        self._poolname = None
        self._volname = None
        self._remote_object_store = None
        self._key = None
        self._local_snapname = None
        self._crypt = None
        self._dedupe = None
        self._compress = None
        self.discriminator = None

        if name is not None:
            self.name = name
        self.mode = mode
        self.poolname = poolname
        self.volname = volname
        self.remote_object_store = remote_object_store
        if key is not None:
            self.key = key
        if local_snapname is not None:
            self.local_snapname = local_snapname
        if crypt is not None:
            self.crypt = crypt
        if dedupe is not None:
            self.dedupe = dedupe
        if compress is not None:
            self.compress = compress

    @property
    def name(self):
        """Gets the name of this CreateRosRestoreJob.  # noqa: E501

        Display Name for object storage restore job  # noqa: E501

        :return: The name of this CreateRosRestoreJob.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateRosRestoreJob.

        Display Name for object storage restore job  # noqa: E501

        :param name: The name of this CreateRosRestoreJob.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def mode(self):
        """Gets the mode of this CreateRosRestoreJob.  # noqa: E501

        mode  # noqa: E501

        :return: The mode of this CreateRosRestoreJob.  # noqa: E501
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this CreateRosRestoreJob.

        mode  # noqa: E501

        :param mode: The mode of this CreateRosRestoreJob.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and mode is None:
            raise ValueError("Invalid value for `mode`, must not be `None`")  # noqa: E501

        self._mode = mode

    @property
    def poolname(self):
        """Gets the poolname of this CreateRosRestoreJob.  # noqa: E501

        Id of created volume's destination pool  # noqa: E501

        :return: The poolname of this CreateRosRestoreJob.  # noqa: E501
        :rtype: str
        """
        return self._poolname

    @poolname.setter
    def poolname(self, poolname):
        """Sets the poolname of this CreateRosRestoreJob.

        Id of created volume's destination pool  # noqa: E501

        :param poolname: The poolname of this CreateRosRestoreJob.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and poolname is None:
            raise ValueError("Invalid value for `poolname`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                poolname is not None and not re.search(r'^pool-[0-9a-f]{8}$', poolname)):  # noqa: E501
            raise ValueError(r"Invalid value for `poolname`, must be a follow pattern or equal to `/^pool-[0-9a-f]{8}$/`")  # noqa: E501

        self._poolname = poolname

    @property
    def volname(self):
        """Gets the volname of this CreateRosRestoreJob.  # noqa: E501

        Name of Created Volume  # noqa: E501

        :return: The volname of this CreateRosRestoreJob.  # noqa: E501
        :rtype: str
        """
        return self._volname

    @volname.setter
    def volname(self, volname):
        """Sets the volname of this CreateRosRestoreJob.

        Name of Created Volume  # noqa: E501

        :param volname: The volname of this CreateRosRestoreJob.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and volname is None:
            raise ValueError("Invalid value for `volname`, must not be `None`")  # noqa: E501

        self._volname = volname

    @property
    def remote_object_store(self):
        """Gets the remote_object_store of this CreateRosRestoreJob.  # noqa: E501

        Id of object storage destination  # noqa: E501

        :return: The remote_object_store of this CreateRosRestoreJob.  # noqa: E501
        :rtype: str
        """
        return self._remote_object_store

    @remote_object_store.setter
    def remote_object_store(self, remote_object_store):
        """Sets the remote_object_store of this CreateRosRestoreJob.

        Id of object storage destination  # noqa: E501

        :param remote_object_store: The remote_object_store of this CreateRosRestoreJob.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and remote_object_store is None:
            raise ValueError("Invalid value for `remote_object_store`, must not be `None`")  # noqa: E501

        self._remote_object_store = remote_object_store

    @property
    def key(self):
        """Gets the key of this CreateRosRestoreJob.  # noqa: E501

        Object storage key from bucket  # noqa: E501

        :return: The key of this CreateRosRestoreJob.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this CreateRosRestoreJob.

        Object storage key from bucket  # noqa: E501

        :param key: The key of this CreateRosRestoreJob.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def local_snapname(self):
        """Gets the local_snapname of this CreateRosRestoreJob.  # noqa: E501

        Object storage local snapshot name  # noqa: E501

        :return: The local_snapname of this CreateRosRestoreJob.  # noqa: E501
        :rtype: str
        """
        return self._local_snapname

    @local_snapname.setter
    def local_snapname(self, local_snapname):
        """Sets the local_snapname of this CreateRosRestoreJob.

        Object storage local snapshot name  # noqa: E501

        :param local_snapname: The local_snapname of this CreateRosRestoreJob.  # noqa: E501
        :type: str
        """

        self._local_snapname = local_snapname

    @property
    def crypt(self):
        """Gets the crypt of this CreateRosRestoreJob.  # noqa: E501

        Enable encryption on volume  # noqa: E501

        :return: The crypt of this CreateRosRestoreJob.  # noqa: E501
        :rtype: str
        """
        return self._crypt

    @crypt.setter
    def crypt(self, crypt):
        """Sets the crypt of this CreateRosRestoreJob.

        Enable encryption on volume  # noqa: E501

        :param crypt: The crypt of this CreateRosRestoreJob.  # noqa: E501
        :type: str
        """

        self._crypt = crypt

    @property
    def dedupe(self):
        """Gets the dedupe of this CreateRosRestoreJob.  # noqa: E501

        Enable Dedupe For Restore Job.  # noqa: E501

        :return: The dedupe of this CreateRosRestoreJob.  # noqa: E501
        :rtype: str
        """
        return self._dedupe

    @dedupe.setter
    def dedupe(self, dedupe):
        """Sets the dedupe of this CreateRosRestoreJob.

        Enable Dedupe For Restore Job.  # noqa: E501

        :param dedupe: The dedupe of this CreateRosRestoreJob.  # noqa: E501
        :type: str
        """

        self._dedupe = dedupe

    @property
    def compress(self):
        """Gets the compress of this CreateRosRestoreJob.  # noqa: E501

        Enable compress or Restore Job.  # noqa: E501

        :return: The compress of this CreateRosRestoreJob.  # noqa: E501
        :rtype: str
        """
        return self._compress

    @compress.setter
    def compress(self, compress):
        """Sets the compress of this CreateRosRestoreJob.

        Enable compress or Restore Job.  # noqa: E501

        :param compress: The compress of this CreateRosRestoreJob.  # noqa: E501
        :type: str
        """

        self._compress = compress

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateRosRestoreJob, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateRosRestoreJob):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateRosRestoreJob):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    zadara api

    zadarapyV2 operations

"""


from setuptools import setup, find_packages  # noqa: H301


NAME = "zadarapyV2"
VERSION = "23.03.01.223" 
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi>=2017.4.17",
    "python-dateutil>=2.1",
    "six>=1.10",
    "urllib3>=1.23"
]
    

setup(
    name=NAME,
    version=VERSION,
    description="zadara api",
    author_email="harel.feldman@zadarastorage.com",
    url="https://github.com/zadarastorage/zadara-clients/tree/master/zadarapyV2",
    keywords=["zadarapy"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    long_description="""\
    Python client for ZADARA storage components:
    Vpsa, Commandcenter, ProvisioningPortal and Zios
    """
)



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class VpsasJsonDrives(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'drive_type': 'str',
        'quantity': 'int'
    }

    attribute_map = {
        'drive_type': 'drive_type',
        'quantity': 'quantity'
    }

    def __init__(self, drive_type=None, quantity=None, _configuration=None):  # noqa: E501
        """VpsasJsonDrives - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._drive_type = None
        self._quantity = None
        self.discriminator = None

        if drive_type is not None:
            self.drive_type = drive_type
        if quantity is not None:
            self.quantity = quantity

    @property
    def drive_type(self):
        """Gets the drive_type of this VpsasJsonDrives.  # noqa: E501


        :return: The drive_type of this VpsasJsonDrives.  # noqa: E501
        :rtype: str
        """
        return self._drive_type

    @drive_type.setter
    def drive_type(self, drive_type):
        """Sets the drive_type of this VpsasJsonDrives.


        :param drive_type: The drive_type of this VpsasJsonDrives.  # noqa: E501
        :type: str
        """

        self._drive_type = drive_type

    @property
    def quantity(self):
        """Gets the quantity of this VpsasJsonDrives.  # noqa: E501


        :return: The quantity of this VpsasJsonDrives.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this VpsasJsonDrives.


        :param quantity: The quantity of this VpsasJsonDrives.  # noqa: E501
        :type: int
        """

        self._quantity = quantity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VpsasJsonDrives, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VpsasJsonDrives):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VpsasJsonDrives):
            return True

        return self.to_dict() != other.to_dict()
